<?php

declare(strict_types=1);

namespace Drupal\search_api_typesense\Ai;

/**
 * Interface for ai_model plugins.
 */
interface AiModelInterface {

  /**
   * Returns the translated plugin label.
   *
   * @return string
   *   The translated plugin label.
   */
  public function label(): string;

  /**
   * Weather the model is remote or not.
   *
   * @return bool
   *   True if the model is remote, false otherwise.
   */
  public function isRemote(): bool;

  /**
   * Weather the model is suitable for embedding or not.
   *
   * @return bool
   *   True if the model is suitable for embedding, false otherwise.
   */
  public function isForEmbedding(): bool;

  /**
   * Weather the model is suitable for conversation or not.
   *
   * @return bool
   *   True if the model is suitable for conversation, false otherwise.
   */
  public function isForConversation(): bool;

  /**
   * Returns the model configuration.
   *
   * @param array $params
   *   The model configuration.
   * @param \Drupal\search_api_typesense\Ai\ConfigurationManagerInterface $configuration_manager
   *   The configuration manager.
   *
   * @return array
   *   The model configuration.
   */
  public function applyConfiguration(
    array $params,
    ConfigurationManagerInterface $configuration_manager,
  ): array;

  /**
   * Build the configuration form.
   *
   * @param array $form
   *   The form array.
   * @param \Drupal\search_api_typesense\Ai\ConfigurationManagerInterface $configuration_manager
   *   The configuration manager.
   *
   * @return array
   *   The form array.
   */
  public function buildConfigurationForm(
    array $form,
    ConfigurationManagerInterface $configuration_manager,
  ): array;

}
