<?php

declare(strict_types=1);

namespace Drupal\search_api_typesense\Ai;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\search_api_typesense\Attribute\AiModel;

/**
 * AiModel plugin manager.
 */
final class AiModelPluginManager extends DefaultPluginManager {

  /**
   * Constructs the object.
   */
  public function __construct(
    \Traversable $namespaces,
    CacheBackendInterface $cache_backend,
    ModuleHandlerInterface $module_handler,
  ) {
    parent::__construct('Plugin/search_api_typesense/AiModel',
      $namespaces, $module_handler, AiModelInterface::class,
      AiModel::class);
    $this->alterInfo('ai_model_info');
    $this->setCacheBackend($cache_backend, 'ai_model_plugins');
  }

  /**
   * Returns the embedding models.
   *
   * @return array
   *   The embedding models.
   */
  public function getEmbeddingModels(): array {
    $models = [];
    foreach ($this->getDefinitions() as $definition) {
      if ($definition['embedding'] === FALSE) {
        continue;
      }

      $models[$definition['id']] = $definition['label'];
    }

    return $models;
  }

  /**
   * Returns the conversation models.
   *
   * @return array
   *   The conversation models.
   */
  public function getConversationModels(): array {
    $models = [];
    foreach ($this->getDefinitions() as $definition) {
      if ($definition['conversation'] === FALSE) {
        continue;
      }

      $models[$definition['id']] = $definition['label'];
    }

    return $models;
  }

}
