<?php

declare(strict_types=1);

namespace Drupal\search_api_typesense\Attribute;

use Drupal\Component\Plugin\Attribute\Plugin;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * The AiModel attribute definition.
 */
#[\Attribute(\Attribute::TARGET_CLASS)]
final class AiModel extends Plugin {

  /**
   * Constructs a new EmbeddingModel instance.
   *
   * @param string $id
   *   The plugin ID.
   * @param string $name
   *   The model name.
   * @param bool $remote
   *   Whether the plugin is remote.
   * @param bool $embedding
   *   Whether the plugin is suitable for embedding.
   * @param bool $conversation
   *   Whether the plugin is suitable for conversation.
   * @param \Drupal\Core\StringTranslation\TranslatableMarkup|null $label
   *   (optional) The human-readable name of the plugin.
   * @param \Drupal\Core\StringTranslation\TranslatableMarkup|null $description
   *   (optional) A brief description of the plugin.
   * @param class-string|null $deriver
   *   (optional) The deriver class.
   *
   * @phpstan-ignore constructor.missingParentCall
   */
  public function __construct(
    public readonly string $id,
    public readonly string $name,
    public readonly bool $remote,
    public readonly bool $embedding,
    public readonly bool $conversation,
    public readonly ?TranslatableMarkup $label,
    public readonly ?TranslatableMarkup $description = NULL,
    public readonly ?string $deriver = NULL,
  ) {
  }

}
