<?php

declare(strict_types=1);

namespace Drupal\search_api_typesense\Plugin\search_api_typesense\AiModel;

use Drupal\Component\Plugin\PluginBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\search_api_typesense\Ai\AiModelInterface;
use Drupal\search_api_typesense\Ai\ConfigurationManagerInterface;
use Drupal\search_api_typesense\Attribute\AiModel;

/**
 * Describe theCloudflare deepseek-coder-6.7b-base-awq conversation model.
 */
#[AiModel(
  id          : 'cloudflare/deepseek-coder-6.7b-base-awq',
  name        : 'deepseek-coder-6.7b-base-awq',
  remote      : FALSE,
  embedding   : FALSE,
  conversation: TRUE,
  label       : new TranslatableMarkup('Cloudflare: deepseek-coder-6.7b-base-awq'),
  description : new TranslatableMarkup('Cloudflare: deepseek-coder-6.7b-base-awq'),
)]
final class DeepseekCoder67Base extends PluginBase implements AiModelInterface {

  use StringTranslationTrait;
  use AiModelTrait;

  /**
   * {@inheritdoc}
   */
  public function applyConfiguration(
    array $params,
    ConfigurationManagerInterface $configuration_manager,
  ): array {
    return $params + [
      'account_id' => $configuration_manager->getValueToStore('account_id'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(
    array $form,
    ConfigurationManagerInterface $configuration_manager,
  ): array {
    $form['account_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Account id'),
      '#default_value' => $configuration_manager->getDefaultValue('account_id'),
      '#required' => TRUE,
    ];

    return $form;
  }

}
