<?php

declare(strict_types=1);

namespace Drupal\search_api_typesense\Plugin\search_api_typesense\AiModel;

use Drupal\Component\Plugin\PluginBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\search_api_typesense\Ai\AiModelInterface;
use Drupal\search_api_typesense\Ai\ConfigurationManagerInterface;

/**
 * Describe OpenAI embedding models.
 */
abstract class OpenAI3Base extends PluginBase implements AiModelInterface {

  use StringTranslationTrait;
  use AiModelTrait;

  /**
   * {@inheritdoc}
   */
  public function applyConfiguration(
    array $params,
    ConfigurationManagerInterface $configuration_manager,
  ): array {
    $embedding_model_config = $configuration_manager->getValueToStore('embedding_model_config');

    return [
      'model_name' => $this->pluginDefinition['name'],
      'api_key' => $embedding_model_config != NULL ? $embedding_model_config['api_key'] : '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(
    array $form,
    ConfigurationManagerInterface $configuration_manager,
  ): array {
    $form = [];

    $embedding_model_config = $configuration_manager->getDefaultValue('embedding_model_config');

    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $embedding_model_config != NULL ? $embedding_model_config['api_key'] : '',
      '#required' => TRUE,
    ];

    return $form;
  }

}
