<?php

declare(strict_types=1);

namespace Drupal\search_api_typesense\Plugin\search_api_typesense\AiModel;

use Drupal\Component\Plugin\PluginBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\search_api_typesense\Ai\AiModelInterface;
use Drupal\search_api_typesense\Ai\ConfigurationManagerInterface;
use Drupal\search_api_typesense\Attribute\AiModel;

/**
 * Describe the OpenAI gpt-3.5-turbo conversation model.
 */
#[AiModel(
  id          : 'openai/gpt-3.5-turbo',
  name        : 'openai_gpt-3.5-turbo',
  remote      : FALSE,
  embedding   : FALSE,
  conversation: TRUE,
  label       : new TranslatableMarkup('OpenAI: gpt-3.5-turbo'),
  description : new TranslatableMarkup('OpenAI: gpt-3.5-turbo'),
)]
final class OpenAIGpt35Turbo extends PluginBase implements AiModelInterface {

  use StringTranslationTrait;
  use AiModelTrait;

  /**
   * {@inheritdoc}
   */
  public function applyConfiguration(
    array $params,
    ConfigurationManagerInterface $configuration_manager,
  ): array {
    $api_key = $configuration_manager->getValueToStore('api_key');

    // Do not send the API key if it is the stored one.
    if (\str_contains($api_key, '********')) {
      return $params;
    }

    return $params + [
      'api_key' => $api_key,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(
    array $form,
    ConfigurationManagerInterface $configuration_manager,
  ): array {
    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $configuration_manager->getDefaultValue('api_key'),
      '#required' => TRUE,
    ];

    return $form;
  }

}
